==> jc-1.4.0.tar.gz: soot/jimple/spark/pag/PAGDumper.h <==
// public class soot.jimple.spark.pag.PAGDumper

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 36b57bc153ba2c79 soot_jimple_spark_pag_PAGDumper

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_pag_PAGDumper_H_
#define _JC_soot_jimple_spark_pag_PAGDumper_H_

// Forward structure declarations
struct _jc_java_io_PrintWriter$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_soot_jimple_spark_pag_Node$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object;
struct _jc_soot_jimple_spark_pag_SparkField$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_PAGDumper$sub_refs	_jc_soot_jimple_spark_pag_PAGDumper$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_PAGDumper$sub_nonrefs	_jc_soot_jimple_spark_pag_PAGDumper$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_PAGDumper$refs	_jc_soot_jimple_spark_pag_PAGDumper$refs;
typedef struct _jc_soot_jimple_spark_pag_PAGDumper$nonrefs	_jc_soot_jimple_spark_pag_PAGDumper$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_PAGDumper$object	_jc_soot_jimple_spark_pag_PAGDumper$object;

typedef const struct _jc_soot_jimple_spark_pag_PAGDumper$vmethods	_jc_soot_jimple_spark_pag_PAGDumper$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_PAGDumper$vtable	_jc_soot_jimple_spark_pag_PAGDumper$vtable;
typedef const struct _jc_soot_jimple_spark_pag_PAGDumper$vtype	_jc_soot_jimple_spark_pag_PAGDumper$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_PAGDumper$method$_init$7a85b1f1b7084100(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *, struct _jc_soot_jimple_spark_pag_PAG$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_soot_jimple_spark_pag_PAGDumper$method$dump$1356784dfb24ffa0(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *);
extern void _jc_soot_jimple_spark_pag_PAGDumper$method$dumpNode$277ad885bc4b364f(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *, struct _jc_soot_jimple_spark_pag_Node$object *, struct _jc_java_io_PrintWriter$object *);
extern void _jc_soot_jimple_spark_pag_PAGDumper$method$dumpPointsToSets$281104d2c7acce7c(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *);
extern void _jc_soot_jimple_spark_pag_PAGDumper$method$dumpTypes$3a3dbef38d91b6e5(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *, struct _jc_java_io_PrintWriter$object *);
extern jint _jc_soot_jimple_spark_pag_PAGDumper$method$fieldToNum$c9baaecb4eea85c2(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_PAGDumper$method_info$dump$1356784dfb24ffa0;
extern _jc_method _jc_soot_jimple_spark_pag_PAGDumper$method_info$dumpNode$277ad885bc4b364f;
extern _jc_method _jc_soot_jimple_spark_pag_PAGDumper$method_info$dumpPointsToSets$281104d2c7acce7c;
extern _jc_method _jc_soot_jimple_spark_pag_PAGDumper$method_info$dumpTypes$3a3dbef38d91b6e5;
extern _jc_method _jc_soot_jimple_spark_pag_PAGDumper$method_info$fieldToNum$c9baaecb4eea85c2;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_PAGDumper$vmethods {
	void	(*dump$1356784dfb24ffa0)(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *);
	void	(*dumpNode$277ad885bc4b364f)(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *, struct _jc_soot_jimple_spark_pag_Node$object *, struct _jc_java_io_PrintWriter$object *);
	void	(*dumpPointsToSets$281104d2c7acce7c)(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *);
	void	(*dumpTypes$3a3dbef38d91b6e5)(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *, struct _jc_java_io_PrintWriter$object *);
	jint	(*fieldToNum$c9baaecb4eea85c2)(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_spark_pag_PAGDumper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_PAGDumper$vmethods	soot_jimple_spark_pag_PAGDumper;
};

// Vtype
struct _jc_soot_jimple_spark_pag_PAGDumper$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_PAGDumper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_PAGDumper$sub_refs {
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
	struct _jc_java_lang_String$object	*output__5fdir;
	struct _jc_java_util_HashMap$object	*fieldMap;
	struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object	*root;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_PAGDumper$refs {
    _jc_soot_jimple_spark_pag_PAGDumper$sub_refs	soot_jimple_spark_pag_PAGDumper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_PAGDumper$sub_nonrefs {
	jint	fieldNum;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_PAGDumper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_PAGDumper$sub_nonrefs	soot_jimple_spark_pag_PAGDumper;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_PAGDumper$object {
	_jc_soot_jimple_spark_pag_PAGDumper$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_PAGDumper$vtype	*vtype;
	_jc_soot_jimple_spark_pag_PAGDumper$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_PAGDumper$vtype _jc_soot_jimple_spark_pag_PAGDumper$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_PAGDumper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_PAGDumper$class_object;

#endif	/* _JC_soot_jimple_spark_pag_PAGDumper_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/pag/PAGDumper.h <==
// public class soot.jimple.spark.pag.PAGDumper

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 36b57bc153ba2c79 soot_jimple_spark_pag_PAGDumper

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_pag_PAGDumper_H_
#define _JC_soot_jimple_spark_pag_PAGDumper_H_

// Forward structure declarations
struct _jc_java_io_PrintWriter$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_soot_jimple_spark_pag_Node$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object;
struct _jc_soot_jimple_spark_pag_SparkField$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_PAGDumper$sub_refs	_jc_soot_jimple_spark_pag_PAGDumper$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_PAGDumper$sub_nonrefs	_jc_soot_jimple_spark_pag_PAGDumper$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_PAGDumper$refs	_jc_soot_jimple_spark_pag_PAGDumper$refs;
typedef struct _jc_soot_jimple_spark_pag_PAGDumper$nonrefs	_jc_soot_jimple_spark_pag_PAGDumper$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_PAGDumper$object	_jc_soot_jimple_spark_pag_PAGDumper$object;

typedef const struct _jc_soot_jimple_spark_pag_PAGDumper$vmethods	_jc_soot_jimple_spark_pag_PAGDumper$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_PAGDumper$vtable	_jc_soot_jimple_spark_pag_PAGDumper$vtable;
typedef const struct _jc_soot_jimple_spark_pag_PAGDumper$vtype	_jc_soot_jimple_spark_pag_PAGDumper$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_PAGDumper$method$_init$7a85b1f1b7084100(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *, struct _jc_soot_jimple_spark_pag_PAG$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_spark_pag_PAGDumper$method$dump$1356784dfb24ffa0(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_pag_PAGDumper$method$dumpNode$277ad885bc4b364f(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *, struct _jc_soot_jimple_spark_pag_Node$object *, struct _jc_java_io_PrintWriter$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_pag_PAGDumper$method$dumpPointsToSets$281104d2c7acce7c(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_pag_PAGDumper$method$dumpTypes$3a3dbef38d91b6e5(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *, struct _jc_java_io_PrintWriter$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_spark_pag_PAGDumper$method$fieldToNum$c9baaecb4eea85c2(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_PAGDumper$method_info$dump$1356784dfb24ffa0;
extern _jc_method _jc_soot_jimple_spark_pag_PAGDumper$method_info$dumpNode$277ad885bc4b364f;
extern _jc_method _jc_soot_jimple_spark_pag_PAGDumper$method_info$dumpPointsToSets$281104d2c7acce7c;
extern _jc_method _jc_soot_jimple_spark_pag_PAGDumper$method_info$dumpTypes$3a3dbef38d91b6e5;
extern _jc_method _jc_soot_jimple_spark_pag_PAGDumper$method_info$fieldToNum$c9baaecb4eea85c2;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_PAGDumper$vmethods {
	void	(*dump$1356784dfb24ffa0)(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *) _JC_JCNI_ATTR;
	void	(*dumpNode$277ad885bc4b364f)(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *, struct _jc_soot_jimple_spark_pag_Node$object *, struct _jc_java_io_PrintWriter$object *) _JC_JCNI_ATTR;
	void	(*dumpPointsToSets$281104d2c7acce7c)(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *) _JC_JCNI_ATTR;
	void	(*dumpTypes$3a3dbef38d91b6e5)(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *, struct _jc_java_io_PrintWriter$object *) _JC_JCNI_ATTR;
	jint	(*fieldToNum$c9baaecb4eea85c2)(_jc_env *, struct _jc_soot_jimple_spark_pag_PAGDumper$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_pag_PAGDumper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_PAGDumper$vmethods	soot_jimple_spark_pag_PAGDumper;
};

// Vtype
struct _jc_soot_jimple_spark_pag_PAGDumper$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_PAGDumper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_PAGDumper$sub_refs {
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
	struct _jc_java_lang_String$object	*output__5fdir;
	struct _jc_java_util_HashMap$object	*fieldMap;
	struct _jc_soot_jimple_spark_pag_PAGDumper__24ObjectNumberer$object	*root;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_PAGDumper$refs {
    _jc_soot_jimple_spark_pag_PAGDumper$sub_refs	soot_jimple_spark_pag_PAGDumper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_PAGDumper$sub_nonrefs {
	jint	fieldNum;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_PAGDumper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_PAGDumper$sub_nonrefs	soot_jimple_spark_pag_PAGDumper;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_PAGDumper$object {
	_jc_soot_jimple_spark_pag_PAGDumper$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_PAGDumper$vtype	*vtype;
	_jc_soot_jimple_spark_pag_PAGDumper$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_PAGDumper$vtype _jc_soot_jimple_spark_pag_PAGDumper$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_PAGDumper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_PAGDumper$class_object;

#endif	/* _JC_soot_jimple_spark_pag_PAGDumper_H_ */
